==> kbear-1.2.src.tar.bz2: kbear-1.2/kbear/kbearwizard.h <==
/***************************************************************************
                          kbearwizard.h  -  description
                             -------------------
    begin                : Wed Jul 19 2000
    copyright            : (C) 2000 by Bjrn Sahlstrm
    email                : bjorn.sahlstrom@mail.bip.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KBEARWIZARD_H
#define KBEARWIZARD_H

//////////////////////////////////////////////////////////////////////
// Qt specific include files
#include <qwidget.h>
#include <qlabel.h>
#include <qpixmap.h>
#include <qtextview.h>
#include <qbuttongroup.h>
#include <qradiobutton.h>
//////////////////////////////////////////////////////////////////////
// KDE specific include files
#include <kwizard.h>
#include <kapp.h>
#include <kiconloader.h>
#include <klocale.h>
//////////////////////////////////////////////////////////////////////
// application specific include files
#include "viewsettingswidget.h"
#include "mixedsettingswidget.h"
#include "childframemodesettings.h"
#include "kbearsitemanager.h"

/**
  *@author Bjrn Sahlstrm
    */

class KBearWizard : public KWizard  {
   Q_OBJECT
public:
	KBearWizard(QWidget *parent=0, const char *name=0);
	~KBearWizard();
	ViewSettingsWidget* settingsWidget() { return (ViewSettingsWidget*)page2; }
	ChildFrameModeSettings* childFrameModeSettings() { return (ChildFrameModeSettings*)page3; }
	MixedSettingsWidget* mixedSettingsWidget() { return (MixedSettingsWidget*)page4; }
protected slots: // Protected slots
  /**  */
  void help();
private: // Private methods
  /** setup the GUI for the wizard */
  void setup();
private: // Private attributes
  QWidget* page1;
  QWidget* page2;
  QWidget* page3;
  QWidget* page4;
  QWidget* page5;
};

#endif

==> kbear-1.2.1.src.tar.bz2: kbear-1.2.1/kbear/kbearwizard.h <==
/***************************************************************************
                          kbearwizard.h  -  description
                             -------------------
    begin                : Wed Jul 19 2000
    copyright            : (C) 2000 by Bjrn Sahlstrm
    email                : bjorn.sahlstrom@mail.bip.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef KBEARWIZARD_H
#define KBEARWIZARD_H

//////////////////////////////////////////////////////////////////////
// Qt specific include files
#include <qwidget.h>
//////////////////////////////////////////////////////////////////////
// KDE specific include files
//////////////////////////////////////////////////////////////////////
// application specific include files
#include "viewsettingswidget.h"
#include "mixedsettingswidget.h"
#include "childframemodesettings.h"
#include "kbearsitemanager.h"
#include "kbearwizardbase.h"

/**
  *@author Bjrn Sahlstrm
    */

class KBearWizard : public KBearWizardBase  {
   Q_OBJECT
public:
	KBearWizard(QWidget *parent=0, const char *name=0);
	~KBearWizard();
	ViewSettingsWidget* settingsWidget() { return (ViewSettingsWidget*)page2; }
	ChildFrameModeSettings* childFrameModeSettings() { return (ChildFrameModeSettings*)page3; }
	MixedSettingsWidget* mixedSettingsWidget() { return (MixedSettingsWidget*)page4; }
protected slots: // Protected slots
  /**  */
  virtual void help();
private: // Private attributes
//  QWidget* page1;
  QWidget* page2;
  QWidget* page3;
  QWidget* page4;
  QWidget* page5;
};

#endif
